@@ -1,4 +1,5 @@
-from typing import Any, Dict, Mapping, Optional, cast
+from collections.abc import Mapping
+from typing import Any, Optional, cast
 
 from dagster import Field, Permissive
 from dagster._config.validate import process_config
@@ -21,7 +22,7 @@ SHARED_CONTAINER_CONTEXT_SCHEMA = Permissive(
 
 # Process fields shared by container contexts in all environments (docker / k8s / ecs etc.)
 def process_shared_container_context_config(
-    container_context_config: Optional[Mapping[str, Any]]
+    container_context_config: Optional[Mapping[str, Any]],
 ) -> Mapping[str, Any]:
     shared_container_context = process_config(
         SHARED_CONTAINER_CONTEXT_SCHEMA, container_context_config or {}
@@ -33,4 +34,4 @@ def process_shared_container_context_config(
             container_context_config,
         )
 
-    return cast(Dict[str, Any], shared_container_context.value)
+    return cast("dict[str, Any]", shared_container_context.value)
