@@ -1,8 +1,10 @@
-from typing import Any, Callable, Mapping, NamedTuple, Optional, Union, cast
+from collections.abc import Mapping
+from typing import Any, Callable, NamedTuple, Optional, Union, cast
 
 from typing_extensions import TypeAlias
 
 import dagster._check as check
+from dagster._annotations import public
 from dagster._builtins import BuiltinEnum
 from dagster._config import (
     ConfigType,
@@ -11,11 +13,12 @@ from dagster._config import (
     resolve_defaults,
     validate_config,
 )
-from dagster._core.definitions.definition_config_schema import IDefinitionConfigSchema
+from dagster._core.definitions.definition_config_schema import (
+    IDefinitionConfigSchema,
+    convert_user_facing_definition_config_schema,
+)
 from dagster._core.errors import DagsterInvalidConfigError
 
-from .definition_config_schema import convert_user_facing_definition_config_schema
-
 ConfigMappingFn: TypeAlias = Callable[[Any], Any]
 
 
@@ -23,6 +26,7 @@ def is_callable_valid_config_arg(config: Union[Callable[..., Any], Mapping[str,
     return BuiltinEnum.contains(config) or is_supported_config_python_builtin(config)
 
 
+@public
 class ConfigMapping(
     NamedTuple(
         "_ConfigMapping",
@@ -40,7 +44,7 @@ class ConfigMapping(
 
     Config mappings require the configuration schema to be specified as ``config_schema``, which will
     be exposed as the configuration schema for the graph, as well as a configuration mapping
-    function, ``config_fn``, which maps the config provided to the composite solid to the config
+    function, ``config_fn``, which maps the config provided to the graph to the config
     that will be provided to the child nodes.
 
     Args:
@@ -59,7 +63,7 @@ class ConfigMapping(
         config_schema: Optional[Any] = None,
         receive_processed_config_values: Optional[bool] = None,
     ):
-        return super(ConfigMapping, cls).__new__(
+        return super().__new__(
             cls,
             config_fn=check.callable_param(config_fn, "config_fn"),
             config_schema=convert_user_facing_definition_config_schema(config_schema),
@@ -69,8 +73,7 @@ class ConfigMapping(
         )
 
     def resolve_from_unvalidated_config(self, config: Any) -> Any:
-        """Validates config against outer config schema, and calls mapping against validated config.
-        """
+        """Validates config against outer config schema, and calls mapping against validated config."""
         receive_processed_config_values = check.opt_bool_param(
             self.receive_processed_config_values, "receive_processed_config_values", default=True
         )
@@ -94,7 +97,7 @@ class ConfigMapping(
         outer_config = outer_evr.value
         if not receive_processed_config_values:
             outer_config = resolve_defaults(
-                cast(ConfigType, self.config_schema.config_type),
+                cast("ConfigType", self.config_schema.config_type),
                 outer_config,
             ).value
 
