@@ -1,11 +1,11 @@
+from collections.abc import Mapping, Sequence
 from inspect import Parameter, Signature, isgeneratorfunction, signature
-from typing import Any, Callable, Mapping, NamedTuple, Optional, Sequence
+from typing import Any, Callable, NamedTuple, Optional
 
-from dagster._seven import is_module_available
+from docstring_parser import parse
 
-from .utils import NoValueSentinel
-
-IS_DOCSTRING_PARSER_AVAILABLE = is_module_available("docstring_parser")
+from dagster._core.decorator_utils import get_type_hints
+from dagster._core.definitions.utils import NoValueSentinel
 
 
 class InferredInputProps(NamedTuple):
@@ -24,13 +24,11 @@ class InferredOutputProps(NamedTuple):
     description: Optional[str]
 
 
-def _infer_input_description_from_docstring(fn: Callable) -> Mapping[str, Optional[str]]:
+def _infer_input_description_from_docstring(fn: Callable[..., Any]) -> Mapping[str, Optional[str]]:
     doc_str = fn.__doc__
-    if not IS_DOCSTRING_PARSER_AVAILABLE or doc_str is None:
+    if doc_str is None:
         return {}
 
-    from docstring_parser import parse
-
     try:
         docstring = parse(doc_str)
         return {p.arg_name: p.description for p in docstring.params}
@@ -38,11 +36,10 @@ def _infer_input_description_from_docstring(fn: Callable) -> Mapping[str, Option
         return {}
 
 
-def _infer_output_description_from_docstring(fn: Callable) -> Optional[str]:
+def _infer_output_description_from_docstring(fn: Callable[..., Any]) -> Optional[str]:
     doc_str = fn.__doc__
-    if not IS_DOCSTRING_PARSER_AVAILABLE or doc_str is None:
+    if doc_str is None:
         return None
-    from docstring_parser import parse
 
     try:
         docstring = parse(doc_str)
@@ -54,12 +51,13 @@ def _infer_output_description_from_docstring(fn: Callable) -> Optional[str]:
         return None
 
 
-def infer_output_props(fn: Callable) -> InferredOutputProps:
-    sig = signature(fn)
-
-    annotation = Parameter.empty
-    if not isgeneratorfunction(fn):
-        annotation = sig.return_annotation
+def infer_output_props(fn: Callable[..., Any]) -> InferredOutputProps:
+    type_hints = get_type_hints(fn)
+    annotation = (
+        type_hints["return"]
+        if not isgeneratorfunction(fn) and "return" in type_hints
+        else Parameter.empty
+    )
 
     return InferredOutputProps(
         annotation=annotation,
@@ -67,13 +65,14 @@ def infer_output_props(fn: Callable) -> InferredOutputProps:
     )
 
 
-def has_explicit_return_type(fn: Callable) -> bool:
+def has_explicit_return_type(fn: Callable[..., Any]) -> bool:
     sig = signature(fn)
     return sig.return_annotation is not Signature.empty
 
 
 def _infer_inputs_from_params(
     params: Sequence[Parameter],
+    type_hints: Mapping[str, object],
     descriptions: Optional[Mapping[str, Optional[str]]] = None,
 ) -> Sequence[InferredInputProps]:
     _descriptions: Mapping[str, Optional[str]] = descriptions or {}
@@ -82,14 +81,14 @@ def _infer_inputs_from_params(
         if param.default is not Parameter.empty:
             input_def = InferredInputProps(
                 param.name,
-                param.annotation,
+                type_hints.get(param.name, param.annotation),
                 default_value=param.default,
                 description=_descriptions.get(param.name),
             )
         else:
             input_def = InferredInputProps(
                 param.name,
-                param.annotation,
+                type_hints.get(param.name, param.annotation),
                 description=_descriptions.get(param.name),
             )
 
@@ -98,10 +97,13 @@ def _infer_inputs_from_params(
     return input_defs
 
 
-def infer_input_props(fn: Callable, context_arg_provided: bool) -> Sequence[InferredInputProps]:
+def infer_input_props(
+    fn: Callable[..., Any], context_arg_provided: bool
+) -> Sequence[InferredInputProps]:
     sig = signature(fn)
     params = list(sig.parameters.values())
+    type_hints = get_type_hints(fn)
     descriptions = _infer_input_description_from_docstring(fn)
     params_to_infer = params[1:] if context_arg_provided else params
-    defs = _infer_inputs_from_params(params_to_infer, descriptions=descriptions)
+    defs = _infer_inputs_from_params(params_to_infer, type_hints, descriptions=descriptions)
     return defs
