@@ -35,7 +35,7 @@ class DefaultPartitionsSubset(
     def get_partition_keys_not_in_subset(
         self, partitions_def: PartitionsDefinition
     ) -> Iterable[str]:
-        return set(partitions_def.get_partition_keys()) - set(self.subset)
+        return [key for key in partitions_def.get_partition_keys() if key not in self.subset]
 
     def get_partition_keys(self) -> Iterable[str]:
         return self.subset
