@@ -1,7 +1,10 @@
+from asyncio import AbstractEventLoop
+from collections.abc import Generator, Mapping
 from contextlib import contextmanager
-from typing import Any, Dict, Generator, Mapping, Optional, cast
+from typing import Any, Optional, cast
 
 import dagster._check as check
+from dagster._annotations import public
 from dagster._config import process_config
 from dagster._core.definitions.resource_definition import (
     ResourceDefinition,
@@ -10,16 +13,15 @@ from dagster._core.definitions.resource_definition import (
 )
 from dagster._core.definitions.run_config import define_resource_dictionary_cls
 from dagster._core.errors import DagsterInvalidConfigError
+from dagster._core.execution.api import ephemeral_instance_if_missing
+from dagster._core.execution.context_creation_job import initialize_console_manager
 from dagster._core.execution.resources_init import resource_initialization_manager
 from dagster._core.instance import DagsterInstance
 from dagster._core.log_manager import DagsterLogManager
+from dagster._core.storage.dagster_run import DagsterRun
 from dagster._core.storage.io_manager import IOManager, IOManagerDefinition
-from dagster._core.storage.pipeline_run import DagsterRun
 from dagster._core.system_config.objects import ResourceConfig, config_map_resources
 
-from .api import ephemeral_instance_if_missing
-from .context_creation_pipeline import initialize_console_manager
-
 
 def get_mapped_resource_config(
     resource_defs: Mapping[str, ResourceDefinition], resource_config: Mapping[str, Any]
@@ -34,10 +36,11 @@ def get_mapped_resource_config(
             config_evr.errors,
             resource_config,
         )
-    config_value = cast(Dict[str, Any], config_evr.value)
+    config_value = cast("dict[str, Any]", config_evr.value)
     return config_map_resources(resource_defs, config_value)
 
 
+@public
 @contextmanager
 def build_resources(
     resources: Mapping[str, Any],
@@ -45,6 +48,7 @@ def build_resources(
     resource_config: Optional[Mapping[str, Any]] = None,
     dagster_run: Optional[DagsterRun] = None,
     log_manager: Optional[DagsterLogManager] = None,
+    event_loop: Optional[AbstractEventLoop] = None,
 ) -> Generator[Resources, None, None]:
     """Context manager that yields resources using provided resource definitions and run config.
 
@@ -67,6 +71,8 @@ def build_resources(
             teardown, this must be provided, or initialization will fail.
         log_manager (Optional[DagsterLogManager]): Log Manager to use during resource
             initialization. Defaults to system log manager.
+        event_loop (Optional[AbstractEventLoop]): An event loop for handling resources
+            with async context managers.
 
     Examples:
         .. code-block:: python
@@ -99,6 +105,7 @@ def build_resources(
             resource_keys_to_init=set(resource_defs.keys()),
             instance=dagster_instance,
             emit_persistent_events=False,
+            event_loop=event_loop,
         )
         try:
             list(resources_manager.generate_setup_events())
@@ -113,18 +120,28 @@ def build_resources(
 
 
 def wrap_resources_for_execution(
-    resources: Optional[Mapping[str, Any]] = None
-) -> Mapping[str, ResourceDefinition]:
-    resources = check.opt_mapping_param(resources, "resources", key_type=str)
-    resource_defs = {}
+    resources: Optional[Mapping[str, Any]] = None,
+) -> dict[str, ResourceDefinition]:
+    return (
+        {
+            resource_key: wrap_resource_for_execution(resource)
+            for resource_key, resource in resources.items()
+        }
+        if resources
+        else {}
+    )
+
+
+def wrap_resource_for_execution(resource: Any) -> ResourceDefinition:
+    from dagster._config.pythonic_config import ConfigurableResourceFactory, PartialResource
+
     # Wrap instantiated resource values in a resource definition.
     # If an instantiated IO manager is provided, wrap it in an IO manager definition.
-    for resource_key, resource in resources.items():
-        if isinstance(resource, ResourceDefinition):
-            resource_defs[resource_key] = resource
-        elif isinstance(resource, IOManager):
-            resource_defs[resource_key] = IOManagerDefinition.hardcoded_io_manager(resource)
-        else:
-            resource_defs[resource_key] = ResourceDefinition.hardcoded_resource(resource)
-
-    return resource_defs
+    if isinstance(resource, (ConfigurableResourceFactory, PartialResource)):
+        return resource.get_resource_definition()
+    elif isinstance(resource, ResourceDefinition):
+        return resource
+    elif isinstance(resource, IOManager):
+        return IOManagerDefinition.hardcoded_io_manager(resource)
+    else:
+        return ResourceDefinition.hardcoded_resource(resource)
