@@ -1,20 +1,19 @@
-import warnings
-from typing import TYPE_CHECKING, AbstractSet, Any, Dict, Mapping, Optional, Set, Union
+from collections.abc import Mapping
+from typing import TYPE_CHECKING, AbstractSet, Any, Optional, Union  # noqa: UP035
 
 import dagster._check as check
 from dagster._annotations import public
-
-from ...definitions.composition import PendingNodeInvocation
-from ...definitions.decorators.graph_decorator import graph
-from ...definitions.dependency import Node
-from ...definitions.hook_definition import HookDefinition
-from ...definitions.op_definition import OpDefinition
-from ...definitions.resource_definition import IContainsGenerator, Resources
-from ...errors import DagsterInvalidPropertyError, DagsterInvariantViolationError
-from ...log_manager import DagsterLogManager
-from ..plan.step import ExecutionStep
-from ..plan.utils import RetryRequestedFromPolicy
-from .system import StepExecutionContext
+from dagster._core.definitions.composition import PendingNodeInvocation
+from dagster._core.definitions.decorators.graph_decorator import graph
+from dagster._core.definitions.dependency import Node
+from dagster._core.definitions.hook_definition import HookDefinition
+from dagster._core.definitions.op_definition import OpDefinition
+from dagster._core.definitions.resource_definition import IContainsGenerator, Resources
+from dagster._core.errors import DagsterInvalidPropertyError, DagsterInvariantViolationError
+from dagster._core.execution.context.system import StepExecutionContext
+from dagster._core.execution.plan.step import ExecutionStep
+from dagster._core.execution.plan.utils import RetryRequestedFromPolicy
+from dagster._core.log_manager import DagsterLogManager
 
 if TYPE_CHECKING:
     from dagster._core.instance import DagsterInstance
@@ -39,28 +38,15 @@ def _check_property_on_test_context(
             f"Attribute '{user_facing_name}' was not provided when "
             f"constructing context. Provide a value for the '{param_on_builder}' parameter on "
             "'build_hook_context'. To learn more, check out the testing hooks section of Dagster's "
-            "concepts docs: https://docs.dagster.io/concepts/ops-jobs-graphs/op-hooks#testing-hooks"
+            "concepts docs: https://legacy-docs.dagster.io/concepts/ops-jobs-graphs/op-hooks#testing-hooks"
         )
     else:
         return value
 
 
+@public
 class HookContext:
-    """The ``context`` object available to a hook function on an DagsterEvent.
-
-    Attributes:
-        log (DagsterLogManager): Centralized log dispatch from user code.
-        hook_def (HookDefinition): The hook that the context object belongs to.
-        op (Op): The op instance associated with the hook.
-        step_key (str): The key for the step where this hook is being triggered.
-        required_resource_keys (Set[str]): Resources required by this hook.
-        resources (Resources): Resources available in the hook context.
-        op_config (Any): The parsed config specific to this op.
-        job_name (str): The name of the job where this hook is being triggered.
-        run_id (str): The id of the run where this hook is being triggered.
-        op_exception (Optional[BaseException]): The thrown exception in a failed op.
-        op_output_values (Dict): Computed output values in an op.
-    """
+    """The ``context`` object available to a hook function on an DagsterEvent."""
 
     def __init__(
         self,
@@ -74,68 +60,61 @@ class HookContext:
             self._required_resource_keys
         )
 
-    @property
-    def pipeline_name(self) -> str:
-        return self.job_name
-
     @public
     @property
     def job_name(self) -> str:
+        """The name of the job where this hook is being triggered."""
         return self._step_execution_context.job_name
 
     @public
     @property
     def run_id(self) -> str:
+        """The id of the run where this hook is being triggered."""
         return self._step_execution_context.run_id
 
     @public
     @property
     def hook_def(self) -> HookDefinition:
+        """The hook that the context object belongs to."""
         return self._hook_def
 
     @public
     @property
     def instance(self) -> "DagsterInstance":
+        """The instance configured to run the current job."""
         return self._step_execution_context.instance
 
     @property
     def op(self) -> Node:
-        return self._step_execution_context.solid
-
-    @property
-    def step(self) -> ExecutionStep:
-        warnings.warn(
-            "The step property of HookContext has been deprecated, and will be removed "
-            "in a future release."
-        )
-        return self._step_execution_context.step
+        """The op instance associated with the hook."""
+        return self._step_execution_context.op
 
     @public
     @property
     def step_key(self) -> str:
+        """The key for the step where this hook is being triggered."""
         return self._step_execution_context.step.key
 
     @public
     @property
     def required_resource_keys(self) -> AbstractSet[str]:
+        """Resources required by this hook."""
         return self._required_resource_keys
 
     @public
     @property
     def resources(self) -> "Resources":
+        """Resources available in the hook context."""
         return self._resources
 
-    @property
-    def solid_config(self) -> Any:
-        solid_config = self._step_execution_context.resolved_run_config.ops.get(
-            str(self._step_execution_context.step.node_handle)
-        )
-        return solid_config.config if solid_config else None
-
     @public
     @property
     def op_config(self) -> Any:
-        return self.solid_config
+        """The parsed config specific to this op."""
+        op_config = self._step_execution_context.resolved_run_config.ops.get(
+            str(self._step_execution_context.step.node_handle)
+        )
+        return op_config.config if op_config else None
 
     # Because of the fact that we directly use the log manager of the step, if a user calls
     # hook_context.log.with_tags, then they will end up mutating the step's logging tags as well.
@@ -143,20 +122,13 @@ class HookContext:
     @public
     @property
     def log(self) -> DagsterLogManager:
+        """Centralized log dispatch from user code."""
         return self._step_execution_context.log
 
-    @property
-    def solid_exception(self) -> Optional[BaseException]:
-        """The thrown exception in a failed solid.
-
-        Returns:
-            Optional[BaseException]: the exception object, None if the solid execution succeeds.
-        """
-        return self.op_exception
-
     @public
     @property
     def op_exception(self) -> Optional[BaseException]:
+        """The thrown exception in a failed op."""
         exc = self._step_execution_context.step_exception
 
         if isinstance(exc, RetryRequestedFromPolicy):
@@ -164,15 +136,16 @@ class HookContext:
 
         return exc
 
+    @public
     @property
-    def solid_output_values(self) -> Mapping[str, Union[Any, Mapping[str, Any]]]:
+    def op_output_values(self) -> Mapping[str, Union[Any, Mapping[str, Any]]]:
         """The computed output values.
 
         Returns a dictionary where keys are output names and the values are:
             * the output values in the normal case
             * a dictionary from mapping key to corresponding value in the mapped case
         """
-        results: Dict[str, Union[Any, Dict[str, Any]]] = {}
+        results: dict[str, Union[Any, dict[str, Any]]] = {}
         captured = self._step_execution_context.step_output_capture
 
         if captured is None:
@@ -194,8 +167,34 @@ class HookContext:
 
     @public
     @property
-    def op_output_values(self):
-        return self.solid_output_values
+    def op_output_metadata(self) -> Mapping[str, Union[Any, Mapping[str, Any]]]:
+        """The applied output metadata.
+
+        Returns a dictionary where keys are output names and the values are:
+            * the applied output metadata in the normal case
+            * a dictionary from mapping key to corresponding metadata in the mapped case
+        """
+        results: dict[str, Union[Any, dict[str, Any]]] = {}
+        captured = self._step_execution_context.step_output_metadata_capture
+
+        if captured is None:
+            check.failed("Outputs were unexpectedly not captured for hook")
+
+        # make the returned values more user-friendly
+        for step_output_handle, metadata in captured.items():
+            if step_output_handle.mapping_key:
+                if results.get(step_output_handle.output_name) is None:
+                    results[step_output_handle.output_name] = {
+                        step_output_handle.mapping_key: metadata
+                    }
+                else:
+                    results[step_output_handle.output_name][step_output_handle.mapping_key] = (
+                        metadata
+                    )
+            else:
+                results[step_output_handle.output_name] = metadata
+
+        return results
 
 
 class UnboundHookContext(HookContext):
@@ -208,8 +207,11 @@ class UnboundHookContext(HookContext):
         op_exception: Optional[Exception],
         instance: Optional["DagsterInstance"],
     ):
-        from ..build_resources import build_resources, wrap_resources_for_execution
-        from ..context_creation_pipeline import initialize_console_manager
+        from dagster._core.execution.build_resources import (
+            build_resources,
+            wrap_resources_for_execution,
+        )
+        from dagster._core.execution.context_creation_job import initialize_console_manager
 
         self._op = None
         if op is not None:
@@ -248,7 +250,9 @@ class UnboundHookContext(HookContext):
 
     @property
     def job_name(self) -> str:
-        return self.pipeline_name
+        return _check_property_on_test_context(
+            self, attr_str="_job_name", user_facing_name="job_name", param_on_builder="job_name"
+        )
 
     @property
     def run_id(self) -> str:
@@ -275,7 +279,7 @@ class UnboundHookContext(HookContext):
         raise DagsterInvalidPropertyError(_property_msg("step_key", "property"))
 
     @property
-    def required_resource_keys(self) -> Set[str]:
+    def required_resource_keys(self) -> set[str]:
         raise DagsterInvalidPropertyError(_property_msg("hook_def", "property"))
 
     @property
@@ -289,8 +293,8 @@ class UnboundHookContext(HookContext):
         return self._resources
 
     @property
-    def solid_config(self) -> Any:
-        raise DagsterInvalidPropertyError(_property_msg("solid_config", "property"))
+    def op_config(self) -> Any:
+        raise DagsterInvalidPropertyError(_property_msg("op_config", "property"))
 
     @property
     def log(self) -> DagsterLogManager:
@@ -301,14 +305,24 @@ class UnboundHookContext(HookContext):
         return self._op_exception
 
     @property
-    def solid_output_values(self) -> Mapping[str, Union[Any, Mapping[str, Any]]]:
+    def op_output_values(self) -> Mapping[str, Union[Any, Mapping[str, Any]]]:
         """The computed output values.
 
         Returns a dictionary where keys are output names and the values are:
             * the output values in the normal case
             * a dictionary from mapping key to corresponding value in the mapped case
         """
-        raise DagsterInvalidPropertyError(_property_msg("solid_output_values", "method"))
+        raise DagsterInvalidPropertyError(_property_msg("op_output_values", "method"))
+
+    @property
+    def op_output_metadata(self) -> Mapping[str, Union[Any, Mapping[str, Any]]]:
+        """The applied output metadata.
+
+        Returns a dictionary where keys are output names and the values are:
+            * the applied output metadata in the normal case
+            * a dictionary from mapping key to corresponding metadata in the mapped case
+        """
+        raise DagsterInvalidPropertyError(_property_msg("op_output_metadata", "method"))
 
     @property
     def instance(self) -> "DagsterInstance":
@@ -381,8 +395,8 @@ class BoundHookContext(HookContext):
         return self._resources
 
     @property
-    def solid_config(self) -> Any:
-        raise DagsterInvalidPropertyError(_property_msg("solid_config", "property"))
+    def op_config(self) -> Any:
+        raise DagsterInvalidPropertyError(_property_msg("op_config", "property"))
 
     @property
     def log(self) -> DagsterLogManager:
@@ -393,14 +407,24 @@ class BoundHookContext(HookContext):
         return self._op_exception
 
     @property
-    def solid_output_values(self) -> Mapping[str, Union[Any, Mapping[str, Any]]]:
+    def op_output_values(self) -> Mapping[str, Union[Any, Mapping[str, Any]]]:
         """The computed output values.
 
         Returns a dictionary where keys are output names and the values are:
             * the output values in the normal case
             * a dictionary from mapping key to corresponding value in the mapped case
         """
-        raise DagsterInvalidPropertyError(_property_msg("solid_output_values", "method"))
+        raise DagsterInvalidPropertyError(_property_msg("op_output_values", "method"))
+
+    @property
+    def op_output_metadata(self) -> Mapping[str, Union[Any, Mapping[str, Any]]]:
+        """The applied output metadata.
+
+        Returns a dictionary where keys are output names and the values are:
+            * the applied output metadata in the normal case
+            * a dictionary from mapping key to corresponding metadata in the mapped case
+        """
+        raise DagsterInvalidPropertyError(_property_msg("op_output_metadata", "method"))
 
     @property
     def instance(self) -> "DagsterInstance":
@@ -413,6 +437,7 @@ class BoundHookContext(HookContext):
         return self._instance
 
 
+@public
 def build_hook_context(
     resources: Optional[Mapping[str, Any]] = None,
     op: Optional[Union[OpDefinition, PendingNodeInvocation]] = None,
