@@ -1,37 +1,30 @@
 import warnings
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    ContextManager,
-    Iterator,
-    List,
-    Mapping,
-    Optional,
-    Sequence,
-    Union,
-    cast,
-)
+from collections.abc import Iterator, Mapping, Sequence
+from typing import TYPE_CHECKING, Any, ContextManager, Optional, Union, cast  # noqa: UP035
 
 import dagster._check as check
-from dagster._annotations import public
-from dagster._core.definitions.asset_layer import AssetOutputInfo
+from dagster._annotations import deprecated, deprecated_param, public
+from dagster._core.definitions.assets.definition.asset_spec import AssetSpec
 from dagster._core.definitions.events import (
     AssetKey,
     AssetMaterialization,
     AssetObservation,
+    CoercibleToAssetKey,
 )
 from dagster._core.definitions.metadata import (
     ArbitraryMetadataMapping,
     MetadataValue,
     RawMetadataValue,
 )
-from dagster._core.definitions.partition_key_range import PartitionKeyRange
-from dagster._core.definitions.time_window_partitions import TimeWindow
+from dagster._core.definitions.partitions.context import partition_loading_context
+from dagster._core.definitions.partitions.partition_key_range import PartitionKeyRange
+from dagster._core.definitions.partitions.utils import TimeWindow
 from dagster._core.errors import DagsterInvalidMetadata, DagsterInvariantViolationError
 from dagster._core.execution.plan.utils import build_resources_for_manager
+from dagster._utils.warnings import normalize_renamed_param
 
 if TYPE_CHECKING:
-    from dagster._core.definitions import PartitionsDefinition, PipelineDefinition
+    from dagster._core.definitions import JobDefinition, PartitionsDefinition
     from dagster._core.definitions.op_definition import OpDefinition
     from dagster._core.definitions.resource_definition import Resources
     from dagster._core.events import DagsterEvent
@@ -45,6 +38,12 @@ if TYPE_CHECKING:
 RUN_ID_PLACEHOLDER = "__EPHEMERAL_RUN_ID"
 
 
+@public
+@deprecated_param(
+    param="metadata",
+    breaking_version="2.0",
+    additional_warn_text="Use `definition_metadata` instead.",
+)
 class OutputContext:
     """The context object that is available to the `handle_output` method of an :py:class:`IOManager`.
 
@@ -52,41 +51,22 @@ class OutputContext:
     `OutputContext` for testing an IO Manager's `handle_output` method, use
     :py:func:`dagster.build_output_context`.
 
-    Attributes:
-        step_key (Optional[str]): The step_key for the compute step that produced the output.
-        name (Optional[str]): The name of the output that produced the output.
-        run_id (Optional[str]): The id of the run that produced the output.
-        metadata (Optional[Mapping[str, RawMetadataValue]]): A dict of the metadata that is assigned to the
-            OutputDefinition that produced the output.
-        mapping_key (Optional[str]): The key that identifies a unique mapped output. None for regular outputs.
-        config (Optional[Any]): The configuration for the output.
-        dagster_type (Optional[DagsterType]): The type of this output.
-        log (Optional[DagsterLogManager]): The log manager to use for this output.
-        version (Optional[str]): (Experimental) The version of the output.
-        resource_config (Optional[Mapping[str, Any]]): The config associated with the resource that
-            initializes the RootInputManager.
-        resources (Optional[Resources]): The resources required by the output manager, specified by the
-            `required_resource_keys` parameter.
-        op_def (Optional[OpDefinition]): The definition of the op that produced the output.
-        asset_info: Optional[AssetOutputInfo]: (Experimental) Asset info corresponding to the
-            output.
-
     Example:
-    .. code-block:: python
+        .. code-block:: python
 
-        from dagster import IOManager, OutputContext
-
-        class MyIOManager(IOManager):
-            def handle_output(self, context: OutputContext, obj):
-                ...
+            from dagster import IOManager, OutputContext
 
+            class MyIOManager(IOManager):
+                def handle_output(self, context: OutputContext, obj):
+                    ...
     """
 
     _step_key: Optional[str]
     _name: Optional[str]
-    _pipeline_name: Optional[str]
+    _job_name: Optional[str]
     _run_id: Optional[str]
-    _metadata: ArbitraryMetadataMapping
+    _definition_metadata: ArbitraryMetadataMapping
+    _output_metadata: ArbitraryMetadataMapping
     _user_generated_metadata: Mapping[str, MetadataValue]
     _mapping_key: Optional[str]
     _config: object
@@ -96,22 +76,22 @@ class OutputContext:
     _version: Optional[str]
     _resource_config: Optional[Mapping[str, object]]
     _step_context: Optional["StepExecutionContext"]
-    _asset_info: Optional[AssetOutputInfo]
+    _asset_key: Optional[AssetKey]
     _warn_on_step_context_use: bool
     _resources: Optional["Resources"]
     _resources_cm: Optional[ContextManager["Resources"]]
     _resources_contain_cm: Optional[bool]
     _cm_scope_entered: Optional[bool]
-    _events: List["DagsterEvent"]
-    _user_events: List[Union[AssetMaterialization, AssetObservation]]
+    _events: list["DagsterEvent"]
+    _user_events: list[Union[AssetMaterialization, AssetObservation]]
 
     def __init__(
         self,
         step_key: Optional[str] = None,
         name: Optional[str] = None,
-        pipeline_name: Optional[str] = None,
+        job_name: Optional[str] = None,
         run_id: Optional[str] = None,
-        metadata: Optional[ArbitraryMetadataMapping] = None,
+        definition_metadata: Optional[ArbitraryMetadataMapping] = None,
         mapping_key: Optional[str] = None,
         config: object = None,
         dagster_type: Optional["DagsterType"] = None,
@@ -121,18 +101,25 @@ class OutputContext:
         resources: Optional[Union["Resources", Mapping[str, object]]] = None,
         step_context: Optional["StepExecutionContext"] = None,
         op_def: Optional["OpDefinition"] = None,
-        asset_info: Optional[AssetOutputInfo] = None,
+        asset_key: Optional[AssetKey] = None,
         warn_on_step_context_use: bool = False,
         partition_key: Optional[str] = None,
+        output_metadata: Optional[Mapping[str, RawMetadataValue]] = None,
+        # deprecated
+        metadata: Optional[ArbitraryMetadataMapping] = None,
     ):
         from dagster._core.definitions.resource_definition import IContainsGenerator, Resources
         from dagster._core.execution.build_resources import build_resources
 
         self._step_key = step_key
         self._name = name
-        self._pipeline_name = pipeline_name
+        self._job_name = job_name
         self._run_id = run_id
-        self._metadata = metadata or {}
+        normalized_metadata = normalize_renamed_param(
+            definition_metadata, "definition_metadata", metadata, "metadata"
+        )
+        self._definition_metadata = normalized_metadata or {}
+        self._output_metadata = output_metadata or {}
         self._mapping_key = mapping_key
         self._config = config
         self._op_def = op_def
@@ -141,7 +128,7 @@ class OutputContext:
         self._version = version
         self._resource_config = resource_config
         self._step_context = step_context
-        self._asset_info = asset_info
+        self._asset_key = asset_key
         self._warn_on_step_context_use = warn_on_step_context_use
         if self._step_context and self._step_context.has_partition_key:
             self._partition_key: Optional[str] = self._step_context.partition_key
@@ -184,6 +171,7 @@ class OutputContext:
     @public
     @property
     def step_key(self) -> str:
+        """The step_key for the compute step that produced the output."""
         if self._step_key is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access step_key, "
@@ -195,6 +183,7 @@ class OutputContext:
     @public
     @property
     def name(self) -> str:
+        """The name of the output that produced the output."""
         if self._name is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access name, "
@@ -204,18 +193,19 @@ class OutputContext:
         return self._name
 
     @property
-    def pipeline_name(self) -> str:
-        if self._pipeline_name is None:
+    def job_name(self) -> str:
+        if self._job_name is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access pipeline_name, "
                 "but it was not provided when constructing the OutputContext"
             )
 
-        return self._pipeline_name
+        return self._job_name
 
     @public
     @property
     def run_id(self) -> str:
+        """The id of the run that produced the output."""
         if self._run_id is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access run_id, "
@@ -224,37 +214,64 @@ class OutputContext:
 
         return self._run_id
 
+    @deprecated(breaking_version="2.0.0", additional_warn_text="Use definition_metadata instead")
     @public
     @property
     def metadata(self) -> Optional[ArbitraryMetadataMapping]:
-        return self._metadata
+        """Deprecated: used definition_metadata instead."""
+        return self._definition_metadata
+
+    @public
+    @property
+    def definition_metadata(self) -> ArbitraryMetadataMapping:
+        """A dict of the metadata that is assigned to the OutputDefinition that produced
+        the output. Metadata is assigned to an OutputDefinition either directly on the OutputDefinition
+        or in the @asset decorator.
+        """
+        return self._definition_metadata
+
+    @public
+    @property
+    def output_metadata(self) -> ArbitraryMetadataMapping:
+        """A dict of the metadata that is assigned to the output at execution time."""
+        if self._warn_on_step_context_use:
+            warnings.warn(
+                "You are using InputContext.upstream_output.output_metadata."
+                "Output metadata is not available when accessed from the InputContext."
+                "https://github.com/dagster-io/dagster/issues/20094"
+            )
+            return {}
+
+        return self._output_metadata
 
     @public
     @property
     def mapping_key(self) -> Optional[str]:
+        """The key that identifies a unique mapped output. None for regular outputs."""
         return self._mapping_key
 
     @public
     @property
     def config(self) -> Any:
+        """The configuration for the output."""
         return self._config
 
     @public
     @property
     def op_def(self) -> "OpDefinition":
-        from dagster._core.definitions import OpDefinition
-
+        """The definition of the op that produced the output."""
         if self._op_def is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access op_def, "
                 "but it was not provided when constructing the OutputContext"
             )
 
-        return cast(OpDefinition, self._op_def)
+        return cast("OpDefinition", self._op_def)
 
     @public
     @property
     def dagster_type(self) -> "DagsterType":
+        """The type of this output."""
         if self._dagster_type is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access dagster_type, "
@@ -266,6 +283,7 @@ class OutputContext:
     @public
     @property
     def log(self) -> "DagsterLogManager":
+        """The log manager to use for this output."""
         if self._log is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access log, "
@@ -277,16 +295,21 @@ class OutputContext:
     @public
     @property
     def version(self) -> Optional[str]:
+        """The version of the output."""
         return self._version
 
     @public
     @property
     def resource_config(self) -> Optional[Mapping[str, object]]:
+        """The config associated with the resource that initializes the InputManager."""
         return self._resource_config
 
     @public
     @property
     def resources(self) -> Any:
+        """The resources required by the output manager, specified by the `required_resource_keys`
+        parameter.
+        """
         if self._resources is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access resources, "
@@ -301,32 +324,32 @@ class OutputContext:
             )
         return self._resources
 
-    @property
-    def asset_info(self) -> Optional[AssetOutputInfo]:
-        return self._asset_info
-
     @public
     @property
     def has_asset_key(self) -> bool:
-        return self._asset_info is not None
+        """Returns True if an asset is being stored, otherwise returns False. A return value of False
+        indicates that an output from an op is being stored.
+        """
+        return self._asset_key is not None
 
     @public
     @property
     def asset_key(self) -> AssetKey:
-        if self._asset_info is None:
+        """The ``AssetKey`` of the asset that is being stored as an output."""
+        if self._asset_key is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access asset_key, "
                 "but it was not provided when constructing the OutputContext"
             )
 
-        return self._asset_info.key
+        return self._asset_key
 
     @public
     @property
     def asset_partitions_def(self) -> "PartitionsDefinition":
         """The PartitionsDefinition on the asset corresponding to this output."""
         asset_key = self.asset_key
-        result = self.step_context.pipeline_def.asset_layer.partitions_def_for_asset(asset_key)
+        result = self.step_context.job_def.asset_layer.get(asset_key).partitions_def
         if result is None:
             raise DagsterInvariantViolationError(
                 f"Attempting to access partitions def for asset {asset_key}, but it is not"
@@ -335,6 +358,13 @@ class OutputContext:
 
         return result
 
+    @public
+    @property
+    def asset_spec(self) -> AssetSpec:
+        """The ``AssetSpec`` that is being stored as an output."""
+        asset_key = self.asset_key
+        return self.step_context.job_def.asset_layer.get(asset_key).to_asset_spec()
+
     @property
     def step_context(self) -> "StepExecutionContext":
         if self._warn_on_step_context_use:
@@ -392,6 +422,7 @@ class OutputContext:
     @public
     @property
     def has_asset_partitions(self) -> bool:
+        """Returns True if the asset being stored is partitioned."""
         if self._warn_on_step_context_use:
             warnings.warn(
                 "You are using InputContext.upstream_output.has_asset_partitions"
@@ -455,10 +486,10 @@ class OutputContext:
                 "For more details: https://github.com/dagster-io/dagster/issues/7900"
             )
 
-        return self.asset_partitions_def.get_partition_keys_in_range(
-            self.step_context.asset_partition_key_range_for_output(self.name),
-            dynamic_partitions_store=self.step_context.instance,
-        )
+        with partition_loading_context(dynamic_partitions_store=self.step_context.instance):
+            return self.asset_partitions_def.get_partition_keys_in_range(
+                self.step_context.asset_partition_key_range_for_output(self.name),
+            )
 
     @public
     @property
@@ -513,9 +544,9 @@ class OutputContext:
             self.name is not None,
             "Unable to find the run scoped output identifier: name is None on OutputContext.",
         )
-        run_id = cast(str, self.run_id)
-        step_key = cast(str, self.step_key)
-        name = cast(str, self.name)
+        run_id = cast("str", self.run_id)
+        step_key = cast("str", self.step_key)
+        name = cast("str", self.name)
 
         if self.mapping_key:
             return [run_id, step_key, name, self.mapping_key]
@@ -548,10 +579,8 @@ class OutputContext:
         if version is not None:
             check.invariant(
                 self.mapping_key is None,
-                (
-                    f"Mapping key and version both provided for output '{name}' of step"
-                    f" '{step_key}'. Dynamic mapping is not supported when using versioning."
-                ),
+                f"Mapping key and version both provided for output '{name}' of step"
+                f" '{step_key}'. Dynamic mapping is not supported when using versioning.",
             )
             identifier = ["versioned_outputs", version, step_key, name]
         else:
@@ -572,6 +601,11 @@ class OutputContext:
 
     @public
     def get_asset_identifier(self) -> Sequence[str]:
+        """The sequence of strings making up the AssetKey for the asset being stored as an output.
+        If the asset is partitioned, the identifier contains the partition key as the final element in the
+        sequence. For example, for the asset key ``AssetKey(["foo", "bar", "baz"])`` materialized with
+        partition key "2023-06-01", ``get_asset_identifier`` will return ``["foo", "bar", "baz", "2023-06-01"]``.
+        """
         if self.asset_key is not None:
             if self.has_asset_partitions:
                 return [*self.asset_key.path, self.asset_partition_key]
@@ -598,13 +632,13 @@ class OutputContext:
             event (Union[AssetMaterialization, AssetObservation]): The event to log.
 
         Examples:
-        .. code-block:: python
+            .. code-block:: python
 
-            from dagster import IOManager, AssetMaterialization
+                from dagster import IOManager, AssetMaterialization
 
-            class MyIOManager(IOManager):
-                def handle_output(self, context, obj):
-                    context.log_event(AssetMaterialization("foo"))
+                class MyIOManager(IOManager):
+                    def handle_output(self, context, obj):
+                        context.log_event(AssetMaterialization("foo"))
         """
         from dagster._core.events import DagsterEvent
 
@@ -666,13 +700,13 @@ class OutputContext:
             metadata (Mapping[str, RawMetadataValue]): A metadata dictionary to log
 
         Examples:
-        .. code-block:: python
+            .. code-block:: python
 
-            from dagster import IOManager
+                from dagster import IOManager
 
-            class MyIOManager(IOManager):
-                def handle_output(self, context, obj):
-                    context.add_output_metadata({"foo": "bar"})
+                class MyIOManager(IOManager):
+                    def handle_output(self, context, obj):
+                        context.add_output_metadata({"foo": "bar"})
         """
         from dagster._core.definitions.metadata import normalize_metadata
 
@@ -710,7 +744,7 @@ class OutputContext:
 
 def get_output_context(
     execution_plan: "ExecutionPlan",
-    pipeline_def: "PipelineDefinition",
+    job_def: "JobDefinition",
     resolved_run_config: "ResolvedRunConfig",
     step_output_handle: "StepOutputHandle",
     run_id: Optional[str],
@@ -719,6 +753,7 @@ def get_output_context(
     resources: Optional["Resources"],
     version: Optional[str],
     warn_on_step_context_use: bool = False,
+    output_metadata: Optional[Mapping[str, RawMetadataValue]] = None,
 ) -> "OutputContext":
     """Args:
     run_id (str): The run ID of the run that produced the output, not necessarily the run that
@@ -726,7 +761,7 @@ def get_output_context(
     """
     step = execution_plan.get_step_by_key(step_output_handle.step_key)
     # get config
-    op_config = resolved_run_config.ops[step.node_handle.to_string()]
+    op_config = resolved_run_config.ops[str(step.node_handle)]
     outputs_config = op_config.outputs
 
     if outputs_config:
@@ -735,69 +770,60 @@ def get_output_context(
         output_config = None
 
     step_output = execution_plan.get_step_output(step_output_handle)
-    output_def = pipeline_def.get_node(step_output.node_handle).output_def_named(step_output.name)
+    output_def = job_def.get_node(step_output.node_handle).output_def_named(step_output.name)
 
     io_manager_key = output_def.io_manager_key
     resource_config = resolved_run_config.resources[io_manager_key].config
 
     node_handle = execution_plan.get_step_by_key(step.key).node_handle
-    asset_info = pipeline_def.asset_layer.asset_info_for_output(
+    asset_key = job_def.asset_layer.get_asset_key_for_node_output(
         node_handle=node_handle, output_name=step_output.name
     )
+    if asset_key is not None:
+        definition_metadata = job_def.asset_layer.get(asset_key).metadata or output_def.metadata
+    else:
+        definition_metadata = output_def.metadata
 
     if step_context:
         check.invariant(
             not resources,
-            (
-                "Expected either resources or step context to be set, but "
-                "received both. If step context is provided, resources for IO manager will be "
-                "retrieved off of that."
-            ),
+            "Expected either resources or step context to be set, but "
+            "received both. If step context is provided, resources for IO manager will be "
+            "retrieved off of that.",
         )
         resources = build_resources_for_manager(io_manager_key, step_context)
 
     return OutputContext(
         step_key=step_output_handle.step_key,
         name=step_output_handle.output_name,
-        pipeline_name=pipeline_def.name,
+        job_name=job_def.name,
         run_id=run_id,
-        metadata=output_def.metadata,
+        definition_metadata=definition_metadata,
         mapping_key=step_output_handle.mapping_key,
         config=output_config,
-        op_def=pipeline_def.get_node(step.node_handle).definition,  # type: ignore  # (should be OpDefinition not NodeDefinition)
+        op_def=job_def.get_node(step.node_handle).definition,  # type: ignore  # (should be OpDefinition not NodeDefinition)
         dagster_type=output_def.dagster_type,
         log_manager=log_manager,
         version=version,
         step_context=step_context,
         resource_config=resource_config,
         resources=resources,
-        asset_info=asset_info,
+        asset_key=asset_key,
         warn_on_step_context_use=warn_on_step_context_use,
+        output_metadata=output_metadata,
     )
 
 
-def step_output_version(
-    pipeline_def: "PipelineDefinition",
-    execution_plan: "ExecutionPlan",
-    resolved_run_config: "ResolvedRunConfig",
-    step_output_handle: "StepOutputHandle",
-) -> Optional[str]:
-    from dagster._core.execution.resolve_versions import resolve_step_output_versions
-
-    step_output_versions = resolve_step_output_versions(
-        pipeline_def, execution_plan, resolved_run_config
-    )
-    return (
-        step_output_versions[step_output_handle]
-        if step_output_handle in step_output_versions
-        else None
-    )
-
-
+@public
+@deprecated_param(
+    param="metadata",
+    breaking_version="2.0",
+    additional_warn_text="Use `definition_metadata` instead.",
+)
 def build_output_context(
     step_key: Optional[str] = None,
     name: Optional[str] = None,
-    metadata: Optional[Mapping[str, RawMetadataValue]] = None,
+    definition_metadata: Optional[Mapping[str, RawMetadataValue]] = None,
     run_id: Optional[str] = None,
     mapping_key: Optional[str] = None,
     config: Optional[Any] = None,
@@ -806,8 +832,10 @@ def build_output_context(
     resource_config: Optional[Mapping[str, object]] = None,
     resources: Optional[Mapping[str, object]] = None,
     op_def: Optional["OpDefinition"] = None,
-    asset_key: Optional[Union[AssetKey, str]] = None,
+    asset_key: Optional[CoercibleToAssetKey] = None,
     partition_key: Optional[str] = None,
+    # deprecated
+    metadata: Optional[Mapping[str, RawMetadataValue]] = None,
 ) -> "OutputContext":
     """Builds output context from provided parameters.
 
@@ -818,12 +846,12 @@ def build_output_context(
     Args:
         step_key (Optional[str]): The step_key for the compute step that produced the output.
         name (Optional[str]): The name of the output that produced the output.
-        metadata (Optional[Mapping[str, Any]]): A dict of the metadata that is assigned to the
+        definition_metadata (Optional[Mapping[str, Any]]): A dict of the metadata that is assigned to the
             OutputDefinition that produced the output.
         mapping_key (Optional[str]): The key that identifies a unique mapped output. None for regular outputs.
         config (Optional[Any]): The configuration for the output.
         dagster_type (Optional[DagsterType]): The type of this output.
-        version (Optional[str]): (Experimental) The version of the output.
+        version (Optional[str]): The version of the output.
         resource_config (Optional[Mapping[str, Any]]): The resource config to make available from the
             input context. This usually corresponds to the config provided to the resource that
             loads the output manager.
@@ -834,6 +862,7 @@ def build_output_context(
         asset_key: Optional[Union[AssetKey, Sequence[str], str]]: The asset key corresponding to the
             output.
         partition_key: Optional[str]: String value representing partition key to execute with.
+        metadata (Optional[Mapping[str, Any]]): Deprecated. Use definition_metadata instead.
 
     Examples:
         .. code-block:: python
@@ -845,12 +874,19 @@ def build_output_context(
 
     """
     from dagster._core.definitions import OpDefinition
-    from dagster._core.execution.context_creation_pipeline import initialize_console_manager
+    from dagster._core.execution.context_creation_job import initialize_console_manager
     from dagster._core.types.dagster_type import DagsterType
 
     step_key = check.opt_str_param(step_key, "step_key")
     name = check.opt_str_param(name, "name")
-    metadata = check.opt_mapping_param(metadata, "metadata", key_type=str)
+    check.opt_mapping_param(definition_metadata, "definition_metadata", key_type=str)
+    check.opt_mapping_param(metadata, "metadata", key_type=str)
+    definition_metadata = normalize_renamed_param(
+        definition_metadata,
+        "definition_metadata",
+        metadata,
+        "metadata",
+    )
     run_id = check.opt_str_param(run_id, "run_id", default=RUN_ID_PLACEHOLDER)
     mapping_key = check.opt_str_param(mapping_key, "mapping_key")
     dagster_type = check.opt_inst_param(dagster_type, "dagster_type", DagsterType)
@@ -858,15 +894,15 @@ def build_output_context(
     resource_config = check.opt_mapping_param(resource_config, "resource_config", key_type=str)
     resources = check.opt_mapping_param(resources, "resources", key_type=str)
     op_def = check.opt_inst_param(op_def, "op_def", OpDefinition)
-    asset_key = AssetKey.from_coerceable(asset_key) if asset_key else None
+    asset_key = AssetKey.from_coercible(asset_key) if asset_key else None
     partition_key = check.opt_str_param(partition_key, "partition_key")
 
     return OutputContext(
         step_key=step_key,
         name=name,
-        pipeline_name=None,
+        job_name=None,
         run_id=run_id,
-        metadata=metadata,
+        definition_metadata=definition_metadata,
         mapping_key=mapping_key,
         config=config,
         dagster_type=dagster_type,
@@ -876,6 +912,6 @@ def build_output_context(
         resources=resources,
         step_context=None,
         op_def=op_def,
-        asset_info=AssetOutputInfo(key=asset_key) if asset_key else None,
+        asset_key=asset_key,
         partition_key=partition_key,
     )
