@@ -75,11 +75,15 @@ def execute_job_backfill_iteration(
             f" {backfill.last_submitted_partition_name}"
         )
 
-    partition_set = _get_partition_set(workspace_process_context, backfill)
-
     # refetch in case the backfill status has changed
     backfill = cast("PartitionBackfill", instance.get_backfill(backfill.backfill_id))
-    if backfill.status == BulkActionStatus.CANCELING:
+    if backfill.status == BulkActionStatus.CANCELING or backfill.status == BulkActionStatus.FAILING:
+        status_once_runs_are_complete = (
+            BulkActionStatus.CANCELED
+            if backfill.status == BulkActionStatus.CANCELING
+            else BulkActionStatus.FAILED
+        )
+
         all_runs_canceled = cancel_backfill_runs_and_cancellation_complete(
             instance=instance,
             backfill_id=backfill.backfill_id,
@@ -88,12 +92,13 @@ def execute_job_backfill_iteration(
 
         if all_runs_canceled:
             instance.update_backfill(
-                backfill.with_status(BulkActionStatus.CANCELED).with_end_timestamp(
+                backfill.with_status(status_once_runs_are_complete).with_end_timestamp(
                     get_current_timestamp()
                 )
             )
         return
 
+    partition_set = _get_partition_set(workspace_process_context, backfill)
     has_more = True
     while has_more:
         if backfill.status != BulkActionStatus.REQUESTED:
