@@ -17,6 +17,7 @@ if TYPE_CHECKING:
     from dagster._core.secrets.loader import SecretsLoader
     from dagster._core.storage.base_storage import DagsterStorage
     from dagster._core.storage.compute_log_manager import ComputeLogManager
+    from dagster._core.storage.defs_state.base import DefsStateStorage
     from dagster._core.storage.event_log.base import EventLogStorage
     from dagster._core.storage.root import LocalArtifactStorage
     from dagster._core.storage.runs.base import RunStorage
@@ -39,6 +40,10 @@ def _schedule_directory(base: str) -> str:
     return os.path.join(base, "schedules")
 
 
+def _defs_state_directory(base: str) -> str:
+    return os.path.join(base, "defs_state")
+
+
 def configurable_class_data(config_field: Mapping[str, Any]) -> ConfigurableClassData:
     return ConfigurableClassData(
         check.str_elem(config_field, "module"),
@@ -206,6 +211,7 @@ class InstanceRef(
             # unified storage field
             ("storage_data", Optional[ConfigurableClassData]),
             ("secrets_loader_data", Optional[ConfigurableClassData]),
+            ("defs_state_storage_data", Optional[ConfigurableClassData]),
         ],
     )
 ):
@@ -228,6 +234,7 @@ class InstanceRef(
         custom_instance_class_data: Optional[ConfigurableClassData] = None,
         storage_data: Optional[ConfigurableClassData] = None,
         secrets_loader_data: Optional[ConfigurableClassData] = None,
+        defs_state_storage_data: Optional[ConfigurableClassData] = None,
     ):
         return super(cls, InstanceRef).__new__(
             cls,
@@ -265,6 +272,9 @@ class InstanceRef(
             secrets_loader_data=check.opt_inst_param(
                 secrets_loader_data, "secrets_loader_data", ConfigurableClassData
             ),
+            defs_state_storage_data=check.opt_inst_param(
+                defs_state_storage_data, "defs_state_storage_data", ConfigurableClassData
+            ),
         )
 
     @staticmethod
@@ -320,6 +330,8 @@ class InstanceRef(
             # so that old clients loading new config don't try to load a class that they
             # don't recognize
             "secrets": None,
+            # For the same reason as `secrets`, this defaults to None
+            "defs_state_storage": None,
             # LEGACY DEFAULTS
             "run_storage": default_run_storage_data,
             "event_log_storage": default_event_log_storage_data,
@@ -449,6 +461,12 @@ class InstanceRef(
             defaults["secrets"],
         )
 
+        defs_state_storage_data = configurable_class_data_or_default(
+            config_value,
+            "defs_state_storage",
+            defaults["defs_state_storage"],
+        )
+
         settings_keys = {
             "telemetry",
             "python_logs",
@@ -479,6 +497,7 @@ class InstanceRef(
             custom_instance_class_data=custom_instance_class_data,
             storage_data=storage_data,
             secrets_loader_data=secrets_loader_data,
+            defs_state_storage_data=defs_state_storage_data,
         )
 
     @staticmethod
@@ -579,6 +598,23 @@ class InstanceRef(
             else PerProjectEnvFileLoader()
         )
 
+    @property
+    def defs_state_storage(self) -> Optional["DefsStateStorage"]:
+        from upath import UPath
+
+        from dagster._core.storage.defs_state.base import DefsStateStorage
+        from dagster._core.storage.defs_state.blob_storage_state_storage import (
+            BlobStorageStateStorage,
+        )
+
+        return (
+            self.defs_state_storage_data.rehydrate(as_type=DefsStateStorage)
+            if self.defs_state_storage_data
+            else BlobStorageStateStorage(
+                UPath(_defs_state_directory(self.local_artifact_storage.base_dir))
+            )
+        )
+
     @property
     def custom_instance_class(self) -> type["DagsterInstance"]:
         return (  # type: ignore  # (ambiguous return type)
