@@ -1,12 +1,21 @@
 from abc import abstractmethod
 from functools import update_wrapper
-from typing import TYPE_CHECKING, AbstractSet, Any, Callable, Optional, Set, Union, cast, overload
+from typing import (  # noqa: UP035
+    TYPE_CHECKING,
+    AbstractSet,
+    Any,
+    Callable,
+    Optional,
+    Union,
+    cast,
+    overload,
+)
 
 from typing_extensions import TypeAlias, TypeGuard
 
 import dagster._check as check
 from dagster._annotations import public
-from dagster._config import UserConfigSchema
+from dagster._core.decorator_utils import get_function_params
 from dagster._core.definitions.config import is_callable_valid_config_arg
 from dagster._core.definitions.definition_config_schema import (
     CoercableToConfigSchema,
@@ -14,13 +23,11 @@ from dagster._core.definitions.definition_config_schema import (
     convert_user_facing_definition_config_schema,
 )
 from dagster._core.definitions.resource_definition import ResourceDefinition
-from dagster._core.storage.input_manager import InputManager
+from dagster._core.storage.input_manager import IInputManagerDefinition, InputManager
 from dagster._core.storage.output_manager import IOutputManagerDefinition, OutputManager
-from dagster._core.storage.root_input_manager import IInputManagerDefinition
-
-from ..decorator_utils import get_function_params
 
 if TYPE_CHECKING:
+    from dagster._config import UserConfigSchema
     from dagster._core.execution.context.init import InitResourceContext
     from dagster._core.execution.context.input import InputContext
     from dagster._core.execution.context.output import OutputContext
@@ -38,6 +45,7 @@ def is_io_manager_context_provided(
     return len(get_function_params(fn)) >= 1
 
 
+@public
 class IOManagerDefinition(ResourceDefinition, IInputManagerDefinition, IOutputManagerDefinition):
     """Definition of an IO manager resource.
 
@@ -71,7 +79,7 @@ class IOManagerDefinition(ResourceDefinition, IInputManagerDefinition, IOutputMa
             if output_config_schema is not None
             else None
         )
-        super(IOManagerDefinition, self).__init__(
+        super().__init__(
             resource_fn=resource_fn,
             config_schema=config_schema,
             description=description,
@@ -84,7 +92,7 @@ class IOManagerDefinition(ResourceDefinition, IInputManagerDefinition, IOutputMa
         return self._input_config_schema
 
     @property
-    def output_config_schema(self) -> Optional[IDefinitionConfigSchema]:
+    def output_config_schema(self) -> Optional[IDefinitionConfigSchema]:  # pyright: ignore[reportIncompatibleMethodOverride]
         return self._output_config_schema
 
     def copy_for_configured(
@@ -92,7 +100,7 @@ class IOManagerDefinition(ResourceDefinition, IInputManagerDefinition, IOutputMa
         description: Optional[str],
         config_schema: CoercableToConfigSchema,
     ) -> "IOManagerDefinition":
-        return IOManagerDefinition(
+        io_def = IOManagerDefinition(
             config_schema=config_schema,
             description=description or self.description,
             resource_fn=self.resource_fn,
@@ -101,6 +109,10 @@ class IOManagerDefinition(ResourceDefinition, IInputManagerDefinition, IOutputMa
             output_config_schema=self.output_config_schema,
         )
 
+        io_def._dagster_maintained = self._is_dagster_maintained()
+
+        return io_def
+
     @public
     @staticmethod
     def hardcoded_io_manager(
@@ -119,6 +131,7 @@ class IOManagerDefinition(ResourceDefinition, IInputManagerDefinition, IOutputMa
         return IOManagerDefinition(resource_fn=lambda _init_context: value, description=description)
 
 
+@public
 class IOManager(InputManager, OutputManager):
     """Base class for user-provided IO managers.
 
@@ -153,8 +166,7 @@ class IOManager(InputManager, OutputManager):
 
 
 @overload
-def io_manager(config_schema: IOManagerFunction) -> IOManagerDefinition:
-    ...
+def io_manager(config_schema: IOManagerFunction) -> IOManagerDefinition: ...
 
 
 @overload
@@ -163,20 +175,23 @@ def io_manager(
     description: Optional[str] = None,
     output_config_schema: CoercableToConfigSchema = None,
     input_config_schema: CoercableToConfigSchema = None,
-    required_resource_keys: Optional[Set[str]] = None,
+    required_resource_keys: Optional[set[str]] = None,
     version: Optional[str] = None,
-) -> Callable[[IOManagerFunction], IOManagerDefinition]:
-    ...
+) -> Callable[[IOManagerFunction], IOManagerDefinition]: ...
 
 
+@public
 def io_manager(
     config_schema: Union[IOManagerFunction, CoercableToConfigSchema] = None,
     description: Optional[str] = None,
     output_config_schema: CoercableToConfigSchema = None,
     input_config_schema: CoercableToConfigSchema = None,
-    required_resource_keys: Optional[Set[str]] = None,
+    required_resource_keys: Optional[set[str]] = None,
     version: Optional[str] = None,
-) -> Union[IOManagerDefinition, Callable[[IOManagerFunction], IOManagerDefinition],]:
+) -> Union[
+    IOManagerDefinition,
+    Callable[[IOManagerFunction], IOManagerDefinition],
+]:
     """Define an IO manager.
 
     IOManagers are used to store op outputs and load them as inputs to downstream ops.
@@ -195,7 +210,7 @@ def io_manager(
             Dagster will accept any config provided.
         required_resource_keys (Optional[Set[str]]): Keys for the resources required by the object
             manager.
-        version (Optional[str]): (Experimental) The version of a resource function. Two wrapped
+        version (Optional[str]): The version of a resource function. Two wrapped
             resource functions should only have the same version if they produce the same resource
             definition when provided with the same inputs.
 
@@ -224,12 +239,12 @@ def io_manager(
 
     """
     if callable(config_schema) and not is_callable_valid_config_arg(config_schema):
-        config_schema = cast(IOManagerFunction, config_schema)
+        config_schema = cast("IOManagerFunction", config_schema)
         return _IOManagerDecoratorCallable()(config_schema)
 
     def _wrap(resource_fn: IOManagerFunction) -> IOManagerDefinition:
         return _IOManagerDecoratorCallable(
-            config_schema=cast(Optional[UserConfigSchema], config_schema),
+            config_schema=cast("Optional[UserConfigSchema]", config_schema),
             description=description,
             required_resource_keys=required_resource_keys,
             version=version,
@@ -240,6 +255,11 @@ def io_manager(
     return _wrap
 
 
+def dagster_maintained_io_manager(io_manager_def: IOManagerDefinition) -> IOManagerDefinition:
+    io_manager_def._dagster_maintained = True  # noqa: SLF001
+    return io_manager_def
+
+
 class _IOManagerDecoratorCallable:
     def __init__(
         self,
@@ -247,7 +267,7 @@ class _IOManagerDecoratorCallable:
         description: Optional[str] = None,
         output_config_schema: CoercableToConfigSchema = None,
         input_config_schema: CoercableToConfigSchema = None,
-        required_resource_keys: Optional[Set[str]] = None,
+        required_resource_keys: Optional[set[str]] = None,
         version: Optional[str] = None,
     ):
         # type validation happens in IOManagerDefinition
