@@ -121,13 +121,16 @@ def execute_backfill_iteration(
     canceling_backfills = instance.get_backfills(
         filters=BulkActionsFilter(statuses=[BulkActionStatus.CANCELING])
     )
+    failing_backfills = instance.get_backfills(
+        filters=BulkActionsFilter(statuses=[BulkActionStatus.FAILING])
+    )
 
-    if not in_progress_backfills and not canceling_backfills:
-        logger.debug("No backfill jobs in progress or canceling.")
+    if not in_progress_backfills and not canceling_backfills and not failing_backfills:
+        logger.debug("No backfill jobs in progress, canceling, or failing.")
         yield None
         return
 
-    backfill_jobs = [*in_progress_backfills, *canceling_backfills]
+    backfill_jobs = [*in_progress_backfills, *canceling_backfills, *failing_backfills]
     backfill_jobs = sorted(backfill_jobs, key=lambda x: x.backfill_timestamp)
 
     yield from execute_backfill_jobs(
@@ -226,10 +229,9 @@ def execute_backfill_iteration_with_instigation_logger(
                     log_message=f"Backfill failed for {backfill.backfill_id}",
                 )
                 instance.update_backfill(
-                    backfill.with_status(BulkActionStatus.FAILED)
+                    backfill.with_status(BulkActionStatus.FAILING)
                     .with_error(error_info)
                     .with_failure_count(backfill.failure_count + 1)
-                    .with_end_timestamp(get_current_timestamp())
                 )
             yield error_info
 
