@@ -1,12 +1,19 @@
 import logging
-from typing import TYPE_CHECKING, Mapping, Optional, Sequence, Tuple
+from collections.abc import Mapping, Sequence
+from typing import TYPE_CHECKING, Optional, Tuple  # noqa: F401, UP035
 
 import coloredlogs
+from dagster_shared import seven
 
-from dagster import _seven
 from dagster._config import Field
 from dagster._core.definitions.logger_definition import LoggerDefinition, logger
+from dagster._core.log_manager import (
+    LOG_RECORD_EVENT_ATTR,
+    LOG_RECORD_METADATA_ATTR,
+    DagsterLogRecordMetadata,
+)
 from dagster._core.utils import coerce_valid_log_level
+from dagster._serdes import pack_value
 from dagster._utils.log import create_console_logger
 
 if TYPE_CHECKING:
@@ -44,6 +51,26 @@ def colored_console_logger(init_context: "InitLoggerContext") -> logging.Logger:
     )
 
 
+class JsonLogFormatter(logging.Formatter):
+    def format(self, record):
+        dict_to_dump = {}
+        for k, v in record.__dict__.items():
+            if k == LOG_RECORD_EVENT_ATTR:
+                # Redundant with the "dagster_event" field under "dagster_meta"
+                continue
+            elif k == LOG_RECORD_METADATA_ATTR:
+                # Events objects are not always JSON-serializable, so need to pack them first
+                json_serializable_event = pack_value(v[LOG_RECORD_EVENT_ATTR])
+                json_serializable_dagster_meta = DagsterLogRecordMetadata(
+                    **{**v, "dagster_event": json_serializable_event}
+                )
+                dict_to_dump[LOG_RECORD_METADATA_ATTR] = json_serializable_dagster_meta
+            else:
+                dict_to_dump[k] = v
+
+        return seven.json.dumps(dict_to_dump)
+
+
 @logger(
     Field(
         {
@@ -68,7 +95,6 @@ def json_console_logger(init_context: "InitLoggerContext") -> logging.Logger:
     """This logger provides support for sending Dagster logs to stdout in json format.
 
     Example:
-
         .. code-block:: python
 
             from dagster import op, job
@@ -92,11 +118,7 @@ def json_console_logger(init_context: "InitLoggerContext") -> logging.Logger:
 
     handler = coloredlogs.StandardErrorHandler()
 
-    class JsonFormatter(logging.Formatter):
-        def format(self, record):
-            return _seven.json.dumps(record.__dict__)
-
-    handler.setFormatter(JsonFormatter())
+    handler.setFormatter(JsonLogFormatter())
     logger_.addHandler(handler)
 
     return logger_
@@ -104,13 +126,13 @@ def json_console_logger(init_context: "InitLoggerContext") -> logging.Logger:
 
 def default_system_loggers(
     instance: Optional["DagsterInstance"],
-) -> Sequence[Tuple["LoggerDefinition", Mapping[str, object]]]:
+) -> Sequence[tuple["LoggerDefinition", Mapping[str, object]]]:
     """If users don't provide configuration for any loggers, we instantiate these loggers with the
     default config.
 
     Returns:
-        List[Tuple[LoggerDefinition, dict]]: Default loggers and their associated configs."""
-
+        List[Tuple[LoggerDefinition, dict]]: Default loggers and their associated configs.
+    """
     log_level = instance.python_log_level if (instance and instance.python_log_level) else "DEBUG"
     return [(colored_console_logger, {"name": "dagster", "log_level": log_level})]
 
