@@ -4,11 +4,6 @@ from dagster.components.testing.deprecated.utils import (
     get_module_path as get_module_path,
     scaffold_defs_sandbox as scaffold_defs_sandbox,
 )
-from dagster.components.testing.test_cases import (
-    TestOpCustomization as TestOpCustomization,
-    TestTranslation as TestTranslation,
-    TestTranslationBatched as TestTranslationBatched,
-)
 from dagster.components.testing.utils import (
     copy_code_to_file as copy_code_to_file,
     create_defs_folder_sandbox as create_defs_folder_sandbox,
